# tinyrox says don't edit this manually, but it can't stop you!

export(mxc_account_fallback_key)
export(mxc_account_generate_one_time_keys)
export(mxc_account_identity_keys)
export(mxc_account_mark_published)
export(mxc_account_new)
export(mxc_account_one_time_keys)
export(mxc_account_pickle)
export(mxc_account_sign)
export(mxc_account_unpickle)
export(mxc_ed25519_verify)
export(mxc_megolm_decrypt)
export(mxc_megolm_encrypt)
export(mxc_megolm_inbound_new)
export(mxc_megolm_inbound_pickle)
export(mxc_megolm_inbound_unpickle)
export(mxc_megolm_outbound_info)
export(mxc_megolm_outbound_new)
export(mxc_megolm_outbound_pickle)
export(mxc_megolm_outbound_unpickle)
export(mxc_olm_create_inbound)
export(mxc_olm_create_outbound)
export(mxc_olm_decrypt)
export(mxc_olm_encrypt)
export(mxc_olm_session_pickle)
export(mxc_olm_session_unpickle)
export(mxc_verify_device_keys)
export(mxc_verify_one_time_key)

useDynLib(mx.crypto, .registration = TRUE)
