# Automatically regenerated. Do not edit.

# .Call(.mxc_account_fallback_key, account)
# .Call(.mxc_account_generate_one_time_keys, account, n)
# .Call(.mxc_account_identity_keys, account)
# .Call(.mxc_account_mark_published, account)
# .Call(.mxc_account_new)
# .Call(.mxc_account_one_time_keys, account)
# .Call(.mxc_account_pickle, account, key)
# .Call(.mxc_account_sign, account, canonical_json)
# .Call(.mxc_account_unpickle, blob, key)
# .Call(.mxc_curve25519_is_valid, public_key_b64)
# .Call(.mxc_ed25519_verify, public_key_b64, message, signature_b64)
# .Call(.mxc_megolm_decrypt, igs, ciphertext_b64)
# .Call(.mxc_megolm_encrypt, gs, plaintext)
# .Call(.mxc_megolm_inbound_new, session_key)
# .Call(.mxc_megolm_inbound_pickle, igs, key)
# .Call(.mxc_megolm_inbound_unpickle, blob, key)
# .Call(.mxc_megolm_outbound_info, gs)
# .Call(.mxc_megolm_outbound_new)
# .Call(.mxc_megolm_outbound_pickle, gs, key)
# .Call(.mxc_megolm_outbound_unpickle, blob, key)
# .Call(.mxc_olm_create_inbound, account, peer_curve25519, prekey_b64)
# .Call(.mxc_olm_create_outbound, account, peer_curve25519, peer_otk)
# .Call(.mxc_olm_decrypt, session, message_type, body)
# .Call(.mxc_olm_encrypt, session, plaintext)
# .Call(.mxc_olm_session_pickle, session, key)
# .Call(.mxc_olm_session_unpickle, blob, key)
